@@ -1,12 +1,12 @@
+package DayDayUp::Context; # make CPAN happy
+
 use MooseX::Declare;
 
 class DayDayUp::Context extends Mojolicious::Context is mutable {
     use MooseX::Types::Moose qw(Str);
     use YAML qw/LoadFile/;
     use KiokuDB;
-    
-    our $VERSION = '0.91';
-    
+
     # shortcuts
     method log  { $self->app->log };
     method home { $self->app->home };
