@@ -1,9 +1,9 @@
+package DayDayUpX::Note; # make CPAN happy
+
 use MooseX::Declare;
 
 class DayDayUpX::Note {
-    
-    our $VERSION = '0.91';
-    
+
     use MooseX::Types::Moose qw(Str Int);
     use Moose::Util::TypeConstraints;
 
